# PurePress

[![PyPI](https://img.shields.io/pypi/v/purepress.svg)](https://pypi.python.org/pypi/purepress)
![Python](https://img.shields.io/badge/python-3.6%2B-blue.svg)

**PurePress** is a very simple static blog generator.

## Usage

```bash
pip install purepress

mkdir my-blog
cd my-blog

purepress init  # init the blog
git clone https://github.com/verilab/purepress-theme-default.git theme  # install a theme

purepress preview  # preview the blog
purepress build  # build the blog
```

See [richardchien/blog](https://github.com/richardchien/blog) for more usage.
